#
# Conditional build:
%bcond_without	doc		# HTML documentation
%bcond_without	qt5		# Qt5 instead of Qt6
%bcond_without	qtwebengine	# map preview using Qt WebEngine
#
%define		qt5_ver	5.12
%define		qt6_ver	6.0
%define         fver	%(echo %{version} | tr . _)

# Qt WebEngine has limited availability
%if %{with qt5}
%ifnarch %{ix86} %{x8664} %{arm} aarch64
%undefine with_qtwebengine
%endif
%else
%ifnarch %{x8664} aarch64
%undefine with_qtwebengine
%endif
%endif

Summary:	GPSBabel - convert GPS waypoint, route and track data
Summary(pl.UTF-8):	GPSBabel - konwertowanie danych GPS: waypointów, tras i śladów
Name:		gpsbabel
Version:	1.9.0
Release:	1
License:	GPL v2+
Group:		Applications/Engineering
# Source0Download via POST form at https://www.gpsbabel.org/download.html#downloading
# version=1.5.4
# token=$(curl -s http://www.gpsbabel.org/download.html | sed -rne 's/.*gpsbabel-'$version'\.tar\.gz.*token.*value="([^"]+)".*/\1/p' | head -n1)
# curl -F "token=$token" -F "dl=gpsbabel-$version.tar.gz" http://www.gpsbabel.org/plan9.php -o gpsbabel-$version.tar.gz
#Source0Download: https://github.com/GPSBabel/gpsbabel/tags
Source0:	https://github.com/GPSBabel/gpsbabel/archive/%{name}_%{fver}.tar.gz
# Source0-md5:	8555b7b4c89fbae832451ed0679e04f0
Source1:	%{name}.desktop
Source2:	%{name}.png
Patch0:		%{name}-no-jing.patch
Patch2:		gmapbase.patch
Patch4:		privacy.patch
URL:		http://www.gpsbabel.org/
BuildRequires:	cmake >= 3.11
BuildRequires:	desktop-file-utils
BuildRequires:	libstdc++-devel >= 6:7
BuildRequires:	libusb-devel >= 1.0
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.605
BuildRequires:	shapelib-devel
BuildRequires:	zlib-devel >= 1.2.9
%if %{with qt5}
BuildRequires:	Qt5Core-devel >= %{qt5_ver}
%else
BuildRequires:	Qt6Core-devel >= %{qt6_ver}
%endif
%if %{with qt5}
BuildRequires:	Qt5Gui-devel >= %{qt5_ver}
BuildRequires:	Qt5Network-devel >= %{qt5_ver}
BuildRequires:	Qt5SerialPort-devel >= %{qt5_ver}
%if %{with qtwebengine}
BuildRequires:	Qt5WebChannel-devel >= %{qt5_ver}
BuildRequires:	Qt5WebEngine-devel >= %{qt5_ver}
%endif
BuildRequires:	Qt5Widgets-devel >= %{qt5_ver}
BuildRequires:	Qt5Xml-devel >= %{qt5_ver}
BuildRequires:	qt5-build >= %{qt5_ver}
BuildRequires:	qt5-linguist >= %{qt5_ver}
BuildRequires:	qt5-qmake >= %{qt5_ver}
%else
BuildRequires:	Qt6Gui-devel >= %{qt6_ver}
BuildRequires:	Qt6Network-devel >= %{qt6_ver}
BuildRequires:	Qt6Qt5Compat-devel >= %{qt6_ver}
BuildRequires:	Qt6SerialPort-devel >= %{qt6_ver}
%if %{with qtwebengine}
BuildRequires:	Qt6WebChannel-devel >= %{qt6_ver}
BuildRequires:	Qt6WebEngine-devel >= %{qt6_ver}
%endif
BuildRequires:	Qt6Widgets-devel >= %{qt6_ver}
BuildRequires:	Qt6Xml-devel >= %{qt6_ver}
BuildRequires:	qt6-build >= %{qt6_ver}
BuildRequires:	qt6-linguist >= %{qt6_ver}
%endif
%if %{with doc}
BuildRequires:	docbook-dtd50-xml
BuildRequires:	docbook-style-xsl-ns
BuildRequires:	libxslt-progs
# xmllint for validation
BuildRequires:	libxml2-progs
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%if %{with qt5}
%define		translationdir	%{_datadir}/qt5/translations
%else
%define		translationdir	%{_datadir}/qt6/translations
%endif

%description
Converts GPS waypoint, route and track data from one format type to
another.

%description -l pl.UTF-8
GPSBabel konwertuje dane GPS: waypointy, trasy i ślady z jednego
formatu na drugi.

%package gui
Summary:	Qt GUI interface for GPSBabel
Summary(pl.UTF-8):	Graficzny interfejs Qt do programu GPSBabel
Group:		Applications/Engineering
Requires:	%{name} = %{version}-%{release}

%description gui
Qt GUI interface for GPSBabel.

%description gui -l pl.UTF-8
Graficzny interfejs Qt do programu GPSBabel.

%prep
%setup -q -n %{name}-%{name}_%{fver}
%patch0 -p1
%patch2 -p1
%patch4 -p1

%if %{with qt5}
%{__sed} -i -e '/QT NAMES / s/Qt6 //' gui/CMakeLists.txt
%endif

%build
install -d build
cd build
%cmake .. \
	%{!?with_qtwebengine:-DGPSBABEL_MAPPREVIEW=OFF} \
	-DGPSBABEL_WITH_SHAPELIB=pkgconfig \
	-DGPSBABEL_WITH_ZLIB=findpackage

%{__make}

%{__make} package_app
cd ..

%if %{with doc}
# docs generation requires in-source build
%cmake . \
	%{!?with_qtwebengine:-DGPSBABEL_MAPPREVIEW=OFF}

%{__make} gpsbabel.html
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_bindir},%{_datadir}/%{name},%{translationdir}}

install build/gui/GPSBabelFE/gpsbabel $RPM_BUILD_ROOT%{_bindir}
install build/gui/GPSBabelFE/gpsbabelfe $RPM_BUILD_ROOT%{_bindir}
cp -p build/gui/GPSBabelFE/gmapbase.html $RPM_BUILD_ROOT%{_datadir}/%{name}
cp -p build/gui/GPSBabelFE/translations/gpsbabel*.qm $RPM_BUILD_ROOT%{translationdir}

desktop-file-install \
	--dir $RPM_BUILD_ROOT%{_desktopdir} \
	%{SOURCE1}

install -d $RPM_BUILD_ROOT%{_iconsdir}/hicolor/256x256/apps
cp -p %{SOURCE2} $RPM_BUILD_ROOT%{_iconsdir}/hicolor/256x256/apps

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc AUTHORS NEWS README.igc README.md SECURITY.md %{?with_doc:gpsbabel.html}
%attr(755,root,root) %{_bindir}/gpsbabel
%lang(de) %{translationdir}/gpsbabel_de.qm
%lang(es) %{translationdir}/gpsbabel_es.qm
%lang(fr) %{translationdir}/gpsbabel_fr.qm
%lang(hu) %{translationdir}/gpsbabel_hu.qm
%lang(it) %{translationdir}/gpsbabel_it.qm
%lang(ru) %{translationdir}/gpsbabel_ru.qm

%files gui
%defattr(644,root,root,755)
%doc gui/{README.gui,TODO}
%attr(755,root,root) %{_bindir}/gpsbabelfe
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/gmapbase.html
%lang(de) %{translationdir}/gpsbabelfe_de.qm
%lang(es) %{translationdir}/gpsbabelfe_es.qm
%lang(fr) %{translationdir}/gpsbabelfe_fr.qm
%lang(hu) %{translationdir}/gpsbabelfe_hu.qm
%lang(it) %{translationdir}/gpsbabelfe_it.qm
%lang(ru) %{translationdir}/gpsbabelfe_ru.qm
%{_desktopdir}/gpsbabel.desktop
%{_iconsdir}/hicolor/*/apps/gpsbabel.png
%changelog
* Wed Jun 26 2024 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/gpsbabel.git;a=log;h=master

* Wed Jun 26 2024 Jakub Bogusz <qboosh@pld-linux.org> 04c8194
- disable jing (uses network to access docbook stylesheets)

* Wed Jun 26 2024 Jakub Bogusz <qboosh@pld-linux.org> 5b53db5
- stick to qt5 by default to have map preview on x86 and consistent qt versions across archs

* Wed Jun 26 2024 Jakub Bogusz <qboosh@pld-linux.org> 239d1ab
- updated to 1.9.0 (defaults to qt6 now); actually package gui executable

* Fri Nov 08 2019 Jan Rękorajski <baggins@pld-linux.org> 72f5406
- rel 1

* Tue Aug 06 2019 Adam Osuchowski <adwol@pld-linux.org> 9de0a52
- preliminary upgrade to 1.6.0

* Wed Dec 12 2018 Adam Gołębiowski <adamg@pld-linux.org> 190316b
- release 3, disable qt5 gui build on x32

* Wed Dec 12 2018 Adam Gołębiowski <adamg@pld-linux.org> 8df74d1
- fix build against shapelib 1.4.1
- use system minizip
- release 2, rebuild against shapelib 1.4.1

* Fri Nov 02 2018 Bartek Szady <bszx@bszx.eu> 5438f53
- updated to 1.5.4

* Sun Nov 23 2014 Bartek Szady <bszx@bszx.eu> cddd20f
- updated to 1.5.1

* Mon Jul 01 2013 Jakub Bogusz <qboosh@pld-linux.org> 7ac20b8
- expat version

* Sun Jun 30 2013 Jakub Bogusz <qboosh@pld-linux.org> 130fab6
- updated download instruction

* Sun Jun 30 2013 wrobell <wrobell@pld-linux.org> 18edc88
- ver. 1.4.4

* Sun Nov 11 2012 Jan Rękorajski <baggins@pld-linux.org> 1cfd810
- rebuild with expat 2.1.0
- release 2 (by relup.sh)

* Sun Feb 19 2012 Jakub Bogusz <qboosh@pld-linux.org> 2526dee
- added link patch
- updated BRs
- pl for -gui

* Sun Feb 12 2012 Elan Ruusamäe <glen@pld-linux.org> e74b4cf
- install gmapbase.html (for google maps preview)

* Sun Feb 12 2012 Elan Ruusamäe <glen@pld-linux.org> 59d976f
- up to 1.4.3

* Sun Feb 12 2012 Elan Ruusamäe <glen@pld-linux.org> 5d02846
- BR qt4-linguist for qt4

* Sun Feb 12 2012 Elan Ruusamäe <glen@pld-linux.org> 9697137
- disable as needed flag

* Fri Sep 02 2011 Elan Ruusamäe <glen@pld-linux.org> db464ee
- use system shapelib; fedora patch

* Thu Sep 01 2011 Elan Ruusamäe <glen@pld-linux.org> fcbff96
- add qt4 gui

